@@ -5,7 +5,7 @@
  *                            | (__| |_| |  _ <| |___
  *                             \___|\___/|_| \_\_____|
  *
- * Copyright (C) 2020 - 2021, Simon Josefsson, <simon@josefsson.org>, et al.
+ * Copyright (C) Simon Josefsson, <simon@josefsson.org>, et al.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution. The terms
@@ -18,26 +18,24 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
+ * SPDX-License-Identifier: curl
+ *
  * RFC5802 SCRAM-SHA-1 authentication
  *
  ***************************************************************************/
 
-#include "curl_setup.h"
+#include "../curl_setup.h"
 
 #ifdef USE_GSASL
 
 #include <curl/curl.h>
 
-#include "vauth/vauth.h"
-#include "urldata.h"
-#include "sendf.h"
+#include "vauth.h"
+#include "../urldata.h"
+#include "../sendf.h"
 
 #include <gsasl.h>
 
-/* The last #include files should be: */
-#include "curl_memory.h"
-#include "memdebug.h"
-
 bool Curl_auth_gsasl_is_supported(struct Curl_easy *data,
                                   const char *mech,
                                   struct gsasldata *gsasl)
@@ -46,7 +44,7 @@ bool Curl_auth_gsasl_is_supported(struct Curl_easy *data,
 
   res = gsasl_init(&gsasl->ctx);
   if(res != GSASL_OK) {
-    failf(data, "gsasl init: %s\n", gsasl_strerror(res));
+    failf(data, "gsasl init: %s", gsasl_strerror(res));
     return FALSE;
   }
 
@@ -56,7 +54,7 @@ bool Curl_auth_gsasl_is_supported(struct Curl_easy *data,
     return FALSE;
   }
 
-  return true;
+  return TRUE;
 }
 
 CURLcode Curl_auth_gsasl_start(struct Curl_easy *data,
@@ -71,7 +69,7 @@ CURLcode Curl_auth_gsasl_start(struct Curl_easy *data,
     gsasl_property_set(gsasl->client, GSASL_AUTHID, userp);
 #if GSASL_VERSION_NUMBER >= 0x010b00
   if(res != GSASL_OK) {
-    failf(data, "setting AUTHID failed: %s\n", gsasl_strerror(res));
+    failf(data, "setting AUTHID failed: %s", gsasl_strerror(res));
     return CURLE_OUT_OF_MEMORY;
   }
 #endif
@@ -82,7 +80,7 @@ CURLcode Curl_auth_gsasl_start(struct Curl_easy *data,
     gsasl_property_set(gsasl->client, GSASL_PASSWORD, passwdp);
 #if GSASL_VERSION_NUMBER >= 0x010b00
   if(res != GSASL_OK) {
-    failf(data, "setting PASSWORD failed: %s\n", gsasl_strerror(res));
+    failf(data, "setting PASSWORD failed: %s", gsasl_strerror(res));
     return CURLE_OUT_OF_MEMORY;
   }
 #endif
@@ -105,7 +103,7 @@ CURLcode Curl_auth_gsasl_token(struct Curl_easy *data,
                    (const char *) Curl_bufref_ptr(chlg), Curl_bufref_len(chlg),
                    &response, &outlen);
   if(res != GSASL_OK && res != GSASL_NEEDS_MORE) {
-    failf(data, "GSASL step: %s\n", gsasl_strerror(res));
+    failf(data, "GSASL step: %s", gsasl_strerror(res));
     return CURLE_BAD_CONTENT_ENCODING;
   }
 
