@@ -31,6 +31,9 @@
  * Macros used in operate()
  */
 
+/* return TRUE if the error code is "lethal" */
+bool setopt_bad(CURLcode result);
+
 #ifndef CURL_DISABLE_LIBCURL_OPTION
 
 /* Associate symbolic names with option values */
@@ -54,6 +57,7 @@ extern const struct NameValue setopt_nv_CURLFTPSSL_CCC[];
 extern const struct NameValue setopt_nv_CURLUSESSL[];
 extern const struct NameValueUnsigned setopt_nv_CURLSSLOPT[];
 extern const struct NameValue setopt_nv_CURL_NETRC[];
+extern const struct NameValue setopt_nv_CURLOPT_FOLLOWLOCATION[];
 extern const struct NameValueUnsigned setopt_nv_CURLAUTH[];
 extern const struct NameValueUnsigned setopt_nv_CURLHSTS[];
 
@@ -75,91 +79,87 @@ extern const struct NameValueUnsigned setopt_nv_CURLHSTS[];
 
 /* Intercept setopt calls for --libcurl */
 
-CURLcode tool_setopt_enum(CURL *curl, struct GlobalConfig *config,
-                          const char *name, CURLoption tag,
+CURLcode tool_setopt_enum(CURL *curl, const char *name, CURLoption tag,
                           const struct NameValue *nv, long lval);
-CURLcode tool_setopt_SSLVERSION(CURL *curl, struct GlobalConfig *config,
-                                const char *name, CURLoption tag,
+CURLcode tool_setopt_SSLVERSION(CURL *curl, const char *name, CURLoption tag,
                                 long lval);
-CURLcode tool_setopt_flags(CURL *curl, struct GlobalConfig *config,
+CURLcode tool_setopt_flags(CURL *curl, struct OperationConfig *config,
                            const char *name, CURLoption tag,
                            const struct NameValue *nv, long lval);
-CURLcode tool_setopt_bitmask(CURL *curl, struct GlobalConfig *config,
+CURLcode tool_setopt_bitmask(CURL *curl,
                              const char *name, CURLoption tag,
                              const struct NameValueUnsigned *nv, long lval);
-CURLcode tool_setopt_mimepost(CURL *curl, struct GlobalConfig *config,
+CURLcode tool_setopt_mimepost(CURL *curl, struct OperationConfig *config,
                               const char *name, CURLoption tag,
                               curl_mime *mimepost);
-CURLcode tool_setopt_slist(CURL *curl, struct GlobalConfig *config,
-                           const char *name, CURLoption tag,
+CURLcode tool_setopt_slist(CURL *curl, const char *name, CURLoption tag,
                            struct curl_slist *list);
-CURLcode tool_setopt_long(CURL *curl, struct GlobalConfig *global,
-                          const char *name, CURLoption tag,
+CURLcode tool_setopt_long(CURL *curl, const char *name, CURLoption tag,
                           long lval);
-CURLcode tool_setopt_offt(CURL *curl, struct GlobalConfig *global,
-                          const char *name, CURLoption tag,
+CURLcode tool_setopt_offt(CURL *curl, const char *name, CURLoption tag,
                           curl_off_t lval);
-CURLcode tool_setopt(CURL *curl, bool str, struct GlobalConfig *global,
-                     struct OperationConfig *config,
-                     const char *name, CURLoption tag, ...);
+CURLcode tool_setopt_str(CURL *curl, struct OperationConfig *config,
+                         const char *name, CURLoption tag,
+                         ...) WARN_UNUSED_RESULT;
+CURLcode tool_setopt_ptr(CURL *curl, const char *name, CURLoption tag, ...);
 
-#define my_setopt(x,y,z) \
-  tool_setopt(x, FALSE, global, config, #y, y, z)
+#define my_setopt_ptr(x,y,z)                    \
+  tool_setopt_ptr(x, #y, y, z)
 
-#define my_setopt_long(x,y,z) \
-  tool_setopt_long(x, global, #y, y, z)
+#define my_setopt_long(x,y,z)                   \
+  tool_setopt_long(x, #y, y, z)
 
-#define my_setopt_offt(x,y,z) \
-  tool_setopt_offt(x, global, #y, y, z)
+#define my_setopt_offt(x,y,z)                   \
+  tool_setopt_offt(x, #y, y, z)
 
-#define my_setopt_str(x,y,z) \
-  tool_setopt(x, TRUE, global, config, #y, y, z)
+#define my_setopt_str(x,y,z)                    \
+  tool_setopt_str(x, config, #y, y, z)
 
-#define my_setopt_enum(x,y,z) \
-  tool_setopt_enum(x, global, #y, y, setopt_nv_ ## y, z)
+/* assumes a 'result' variable to use. If the return code is benign it is left
+   in 'result' after this call, otherwise the function returns the error */
+#define MY_SETOPT_STR(x,y,z)                                     \
+  do {                                                           \
+    result = tool_setopt_str(x, config, #y, y, z);               \
+    if(setopt_bad(result))                                       \
+      return result;                                             \
+  } while(0)
 
-#define my_setopt_SSLVERSION(x,y,z) \
-  tool_setopt_SSLVERSION(x, global, #y, y, z)
+#define my_setopt_enum(x,y,z)                           \
+  tool_setopt_enum(x, #y, y, setopt_nv_ ## y, z)
 
-#define my_setopt_bitmask(x,y,z) \
-  tool_setopt_bitmask(x, global, #y, y, setopt_nv_ ## y, z)
+#define my_setopt_SSLVERSION(x,y,z)             \
+  tool_setopt_SSLVERSION(x, #y, y, z)
 
-#define my_setopt_mimepost(x,y,z) \
-  tool_setopt_mimepost(x, global, #y, y, z)
+#define my_setopt_bitmask(x,y,z)                        \
+  tool_setopt_bitmask(x, #y, y, setopt_nv_ ## y, z)
 
-#define my_setopt_slist(x,y,z) \
-  tool_setopt_slist(x, global, #y, y, z)
+#define my_setopt_mimepost(x,y,z)               \
+  tool_setopt_mimepost(x, config, #y, y, z)
+
+#define my_setopt_slist(x,y,z)                  \
+  tool_setopt_slist(x, #y, y, z)
 
 #else /* CURL_DISABLE_LIBCURL_OPTION */
 
 /* No --libcurl, so pass options directly to library */
 
-#define my_setopt(x,y,z) \
-  curl_easy_setopt(x, y, z)
+#define my_setopt_long(x,y,z) curl_easy_setopt(x, y, (long)(z))
+#define my_setopt_offt(x,y,z) curl_easy_setopt(x, y, (curl_off_t)(z))
+#define my_setopt_ptr(x,y,z) curl_easy_setopt(x, y, z)
+#define my_setopt_str(x,y,z) curl_easy_setopt(x, y, z)
+#define my_setopt_enum(x,y,z) curl_easy_setopt(x, y, z)
+#define my_setopt_SSLVERSION(x,y,z) curl_easy_setopt(x, y, z)
+#define my_setopt_bitmask(x,y,z) curl_easy_setopt(x, y, (long)z)
+#define my_setopt_mimepost(x,y,z) curl_easy_setopt(x, y, z)
+#define my_setopt_slist(x,y,z) curl_easy_setopt(x, y, z)
 
-#define my_setopt_long(x,y,z) \
-  curl_easy_setopt(x, y, (long)(z))
+#define MY_SETOPT_STR(x,y,z)                            \
+  do {                                                  \
+    result = curl_easy_setopt(x, y, z);                 \
+    if(setopt_bad(result))                              \
+      return result;                                    \
+  } while(0)
 
-#define my_setopt_offt(x,y,z) \
-  curl_easy_setopt(x, y, (curl_off_t)(z))
-
-#define my_setopt_str(x,y,z)                    \
-  curl_easy_setopt(x, y, z)
-
-#define my_setopt_enum(x,y,z) \
-  curl_easy_setopt(x, y, z)
-
-#define my_setopt_SSLVERSION(x,y,z) \
-  curl_easy_setopt(x, y, z)
-
-#define my_setopt_bitmask(x,y,z) \
-  curl_easy_setopt(x, y, (long)z)
-
-#define my_setopt_mimepost(x,y,z) \
-  curl_easy_setopt(x, y, z)
-
-#define my_setopt_slist(x,y,z) \
-  curl_easy_setopt(x, y, z)
 
 #endif /* CURL_DISABLE_LIBCURL_OPTION */
 
